diff data/fileio/CSVFileReader.cpp @ 690:1424aa29ae95

Seems to be a bad idea to use plain DEBUG symbol on OS/X (system wants it)
author Chris Cannam
date Tue, 14 Jun 2011 15:26:52 +0100
parents 06f13a3b9e9e
children e802e550a1f2
line wrap: on
line diff
--- a/data/fileio/CSVFileReader.cpp	Tue Jun 14 14:47:59 2011 +0100
+++ b/data/fileio/CSVFileReader.cpp	Tue Jun 14 15:26:52 2011 +0100
@@ -59,10 +59,10 @@
 
 CSVFileReader::~CSVFileReader()
 {
-    DEBUG << "CSVFileReader::~CSVFileReader: file is " << m_file << endl;
+    SVDEBUG << "CSVFileReader::~CSVFileReader: file is " << m_file << endl;
 
     if (m_file) {
-        DEBUG << "CSVFileReader::CSVFileReader: Closing file" << endl;
+        SVDEBUG << "CSVFileReader::CSVFileReader: Closing file" << endl;
         m_file->close();
     }
     delete m_file;
@@ -345,7 +345,7 @@
                     }
                 }
 	
 //                DEBUG << "Setting bin values for count " << lineno << ", frame "
 //                          << frameNo << ", time " << RealTime::frame2RealTime(frameNo, sampleRate) << endl;
 
                 model3->setColumn(lineno, values);
@@ -345,7 +345,7 @@
                 }
 	
-//                DEBUG << "Setting bin values for count " << lineno << ", frame "
+//                SVDEBUG << "Setting bin values for count " << lineno << ", frame "
 //                          << frameNo << ", time " << RealTime::frame2RealTime(frameNo, sampleRate) << endl;
 